[Pkg-owncloud-commits] [owncloud] 20/103: fix filesystem and encryption tests

David Prévot taffit at moszumanska.debian.org
Sun May 31 12:32:34 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to annotated tag v8.0.4RC1
in repository owncloud.

commit ac062bd0aad015b14f3b1f053f7f16bb14c74b5a
Author: Jörn Friedrich Dreyer <jfd at butonic.de>
Date:   Thu Apr 2 11:28:10 2015 +0200

    fix filesystem and encryption tests
    
    Conflicts:
    	apps/files_encryption/lib/util.php
    	apps/files_encryption/tests/hooks.php
---
 tests/lib/files/filesystem.php | 11 ++++-------
 1 file changed, 4 insertions(+), 7 deletions(-)

diff --git a/tests/lib/files/filesystem.php b/tests/lib/files/filesystem.php
index 7bf5931..5acfb1f 100644
--- a/tests/lib/files/filesystem.php
+++ b/tests/lib/files/filesystem.php
@@ -22,6 +22,8 @@
 
 namespace Test\Files;
 
+use OC\User\NoUserException;
+
 class Filesystem extends \Test\TestCase {
 	/**
 	 * @var array tmpDirs
@@ -267,19 +269,14 @@ class Filesystem extends \Test\TestCase {
 	}
 
 	/**
 	 * Tests that a local storage mount is used when passed user
 	 * does not exist.
 	 */
 	public function testLocalMountWhenUserDoesNotExist() {
 		$datadir = \OC_Config::getValue("datadirectory", \OC::$SERVERROOT . "/data");
 		$userId = $this->getUniqueID('user_');
 
 		\OC\Files\Filesystem::initMountPoints($userId);
-
-		$homeMount = \OC\Files\Filesystem::getStorage('/' . $userId . '/');
-
-		$this->assertTrue($homeMount->instanceOfStorage('\OC\Files\Storage\Local'));
-		$this->assertEquals('local::' . $datadir . '/' . $userId . '/', $homeMount->getId());
 	}
 
 	/**
@@ -267,19 +269,14 @@ class Filesystem extends \Test\TestCase {
 
 	/**
-	 * Tests that a local storage mount is used when passed user
-	 * does not exist.
+	 * Tests that an exception is thrown when passed user does not exist.
+	 * @expectedException \OC\User\NoUserException
 	 */
 	public function testLocalMountWhenUserDoesNotExist() {

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list